@@ -5,12 +5,14 @@ bread <- function(x, ...)
 
 bread.lm <- function(x, ...)
 {
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   sx <- summary.lm(x)
   return(sx$cov.unscaled * as.vector(sum(sx$df[1:2])))
 }
 
 bread.mlm <- function(x, ...)
 {
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   sx <- summary.lm(x)
   rval <- diag(ncol(residuals(x))) %x% sx$cov.unscaled * as.vector(sum(sx$df[1:2]))
   colnames(rval) <- rownames(rval) <- colnames(vcov(x))
@@ -19,6 +21,7 @@ bread.mlm <- function(x, ...)
 
 bread.glm <- function(x, ...)
 {
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   sx <- summary(x)
   wres <- as.vector(residuals(x, "working")) * weights(x, "working")
   dispersion <- if(substr(x$family$family, 1, 17) %in% c("poisson", "binomial", "Negative Binomial")) 1
@@ -28,6 +31,7 @@ bread.glm <- function(x, ...)
 
 bread.nls <- function(x, ...)
 {
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   sx <- summary(x)
   return(sx$cov.unscaled * as.vector(sum(sx$df[1:2])))
 }
@@ -47,6 +51,7 @@ bread.survreg <- function(x, ...)
 
 bread.gam <- function(x, ...)
 {
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   sx <- summary(x)
   sx$cov.unscaled * sx$n
 }
@@ -59,20 +64,25 @@ bread.coxph <- function(x, ...)
 
 }
 
-bread.hurdle <- function(x, ...) {
+bread.hurdle <- function(x, ...)
+{
   x$vcov * x$n
 }
 
-bread.zeroinfl <- function(x, ...) {
+bread.zeroinfl <- function(x, ...)
+{
   x$vcov * x$n
 }
 
 bread.mlogit <- function(x, ...)
 {
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   vcov(x) * length(residuals(x))
 }
 
-bread.rlm <- function(x, ...) {
+bread.rlm <- function(x, ...)
+{
+  if(!is.null(x$na.action)) class(x$na.action) <- "omit"
   xmat <- model.matrix(x)
   xmat <- naresid(x$na.action, xmat)
   wts <- weights(x)
